@@ -1,5 +1,5 @@
 import tarfile
-import pickle as _pickle
+import _pickle
 from os import path, makedirs, listdir
 
 '''Utility methods used by other classes
